@@ -12,8 +12,14 @@ def handle_error_in_initialization(e):
         logger.info("Exiting due to initialization error.")
         sys.exit(1)
 
+Icon = None
 
 try:
+    import GameSentenceMiner.util.configuration
+    from GameSentenceMiner.util.configuration import logger, gsm_state, get_config, anki_results, AnkiUpdateResult, \
+    get_temporary_directory, get_log_path, get_master_config, switch_profile_and_save, get_app_directory, gsm_status, \
+    is_windows, is_linux, get_ffmpeg_path
+    
     import asyncio
     import os
     import shutil
@@ -33,16 +39,16 @@ try:
     import keyboard
     import ttkbootstrap as ttk
     from PIL import Image
-    from pystray import Icon, Menu, MenuItem
+    try:
+        pass
+        # from pystray import Icon, Menu, MenuItem
+    except Exception:
+        logger.warning("pystray not installed correctly, tray icon will not work.")
     from watchdog.events import FileSystemEventHandler
     from watchdog.observers import Observer
     import psutil
 
     start_time = time.time()
-    import GameSentenceMiner.util.configuration
-    from GameSentenceMiner.util.configuration import logger, gsm_state, get_config, anki_results, AnkiUpdateResult, \
-    get_temporary_directory, get_log_path, get_master_config, switch_profile_and_save, get_app_directory, gsm_status, \
-    is_windows, is_linux, get_ffmpeg_path
 
     logger.debug(f"[Import] configuration: {time.time() - start_time:.3f}s")
     
@@ -443,9 +449,15 @@ class GSMTray(threading.Thread):
         self.icon = None
 
     def run(self):
+        if not Icon:
+            logger.warning("Tray icon functionality is not available.")
+            return
         self.run_tray()
 
     def run_tray(self):
+        if not Icon:
+            logger.warning("Tray icon functionality is not available.")
+            return
         def run_anki_confirmation_window():
             settings_window.show_anki_confirmation_dialog(expression="こんにちは",
                 sentence="こんにちは、世界！元気ですか？",
@@ -475,6 +487,8 @@ class GSMTray(threading.Thread):
 
     def update_icon(self, profile=None):
         global menu, icon
+        if not self.icon:
+            return
         # Recreate the menu with the updated button text
         profile_menu = Menu(
             *[MenuItem(("Active: " if profile == get_master_config().current_profile else "") + profile, self.switch_profile) for
@@ -496,6 +510,8 @@ class GSMTray(threading.Thread):
         self.icon.update_menu()
 
     def switch_profile(self, icon, item):
+        if not self.icon:
+            return
         if "Active:" in item.text:
             logger.error("You cannot switch to the currently active profile!")
             return
@@ -509,11 +525,15 @@ class GSMTray(threading.Thread):
             send_restart_signal()
 
     def play_pause(self, icon, item):
+        if not self.icon:
+            return
         global obs_paused, menu
         obs.toggle_replay_buffer()
         self.update_icon()
 
     def stop(self):
+        if not self.icon:
+            return
         if self.icon:
             self.icon.stop()
 
@@ -861,13 +881,15 @@ async def async_main(reloading=False):
         try:
             if get_config().general.open_config_on_startup:
                 root.after(50, settings_window.show)
-            root.after(50, gsm_tray.start)
+            if Icon:
+                root.after(50, gsm_tray.start)
             # root.after(100, settings_window.show_anki_confirmation_dialog(expression="こんにちは",
             #     sentence="こんにちは、世界！元気ですか？",
             #     screenshot_path="test_image.png",
             #     audio_path="C:/path/to/my/audio.mp3",
             #     translation="Hello world! How are you?"))
-            settings_window.add_save_hook(gsm_tray.update_icon)
+            if Icon:
+                settings_window.add_save_hook(gsm_tray.update_icon)
             settings_window.add_save_hook(on_config_changed)
             settings_window.on_exit = exit_program
             root.mainloop()
