@@ -12,7 +12,7 @@ from logging.handlers import RotatingFileHandler
 from os.path import expanduser
 from sys import platform
 import time
-from typing import List, Dict
+from typing import Any, List, Dict
 import sys
 from enum import Enum
 
@@ -59,6 +59,28 @@ supported_formats = {
     'm4a': 'aac',
 }
 
+KNOWN_ASPECT_RATIOS = [
+    # --- Classic / Legacy ---
+    {"name": "4:3 (SD / Retro Games)", "ratio": 4 / 3},
+    {"name": "5:4 (Old PC Monitors)", "ratio": 5 / 4},
+    {"name": "3:2 (Handheld / GBA / DS / DSLR)", "ratio": 3 / 2},
+
+    # --- Modern Displays ---
+    {"name": "16:10 (PC Widescreen)", "ratio": 16 / 10},
+    {"name": "16:9 (Standard HD / 1080p / 4K)", "ratio": 16 / 9},
+    {"name": "18:9 (Mobile / Some Modern Laptops)", "ratio": 18 / 9},
+    {"name": "19.5:9 (Modern Smartphones)", "ratio": 19.5 / 9},
+    {"name": "21:9 (UltraWide)", "ratio": 21 / 9},
+    {"name": "24:10 (UltraWide+)", "ratio": 24 / 10},
+    {"name": "32:9 (Super UltraWide)", "ratio": 32 / 9},
+
+    # --- Vertical / Mobile ---
+    {"name": "9:16 (Portrait Mode)", "ratio": 9 / 16},
+    {"name": "3:4 (Portrait 4:3)", "ratio": 3 / 4},
+    {"name": "1:1 (Square / UI Capture)", "ratio": 1 / 1},
+]
+
+KNOWN_ASPECT_RATIOS_DICT = {item["name"]: item["ratio"] for item in KNOWN_ASPECT_RATIOS}
 
 def is_linux():
     return platform == 'linux'
@@ -470,7 +492,6 @@ class Features:
     open_anki_edit: bool = False
     open_anki_in_browser: bool = True
     browser_query: str = ''
-    backfill_audio: bool = False
     generate_longplay: bool = False
 
 
@@ -491,6 +512,7 @@ class Screenshot:
     use_new_screenshot_logic: bool = False
     screenshot_timing_setting: str = 'beginning'  # 'middle', 'end'
     use_screenshot_selector: bool = False
+    trim_black_bars_wip: bool = True
 
     def __post_init__(self):
         if not self.screenshot_timing_setting and self.use_beginning_of_line_as_screenshot:
@@ -633,6 +655,7 @@ class Ai:
     use_canned_translation_prompt: bool = True
     use_canned_context_prompt: bool = False
     custom_prompt: str = ''
+    custom_texthooker_prompt: str = ''
     dialogue_context_length: int = 10
 
     def __post_init__(self):
@@ -676,8 +699,10 @@ class Overlay:
     monitor_to_capture: int = 0
     periodic: bool = False
     periodic_interval: float = 1.0
+    periodic_ratio: float = 0.9
     scan_delay: float = 0.25
     minimum_character_size: int = 0
+    number_of_local_scans_per_event: int = 1
 
     def __post_init__(self):
         if self.monitor_to_capture == -1:
@@ -761,9 +786,7 @@ class ProfileConfig:
             'notify_on_update', self.features.notify_on_update)
         self.features.open_anki_edit = config_data['features'].get(
             'open_anki_edit', self.features.open_anki_edit)
-        self.features.backfill_audio = config_data['features'].get(
-            'backfill_audio', self.features.backfill_audio)
-
+        
         self.screenshot.width = config_data['screenshot'].get(
             'width', self.screenshot.width)
         self.screenshot.height = config_data['screenshot'].get(
@@ -905,6 +928,7 @@ class Config:
                         if profile.vad.selected_vad_model == WHISPER and profile.vad.backup_vad_model == SILERO:
                             profile.vad.backup_vad_model = OFF
 
+                self.version = current_version
                 self.save()
 
     def save(self):
@@ -1175,31 +1199,22 @@ def get_config():
     global config_instance
     if config_instance is None:
         config_instance = load_config()
-        config = config_instance.get_config()
-
-        if config.features.backfill_audio and config.features.full_auto:
-            logger.warning(
-                "Backfill audio is enabled, but full auto is also enabled. Disabling backfill...")
-            config.features.backfill_audio = False
 
     # print(config_instance.get_config())
     return config_instance.get_config()
 
+
 def get_overlay_config():
     global config_instance
     if config_instance is None:
         config_instance = load_config()
     return config_instance.overlay
 
+
 def reload_config():
     global config_instance
     config_instance = load_config()
-    config = config_instance.get_config()
 
-    if config.features.backfill_audio and config.features.full_auto:
-        logger.warning(
-            "Backfill is enabled, but full auto is also enabled. Disabling backfill...")
-        config.features.backfill_audio = False
         
 def get_stats_config():
     global config_instance
@@ -1315,6 +1330,7 @@ class GsmAppState:
         self.current_srt = None
         self.srt_index = 1
         self.current_audio_stream = None
+        self.replay_buffer_length = 0
 
 
 @dataclass_json
@@ -1329,10 +1345,11 @@ class AnkiUpdateResult:
     video_in_anki: str = ''
     word_path: str = ''
     word: str = ''
+    extra_tags: List[str] = field(default_factory=list)
 
     @staticmethod
     def failure():
-        return AnkiUpdateResult(success=False, audio_in_anki='', screenshot_in_anki='', prev_screenshot_in_anki='', sentence_in_anki='', multi_line=False, video_in_anki='', word_path='', word='')
+        return AnkiUpdateResult(success=False, audio_in_anki='', screenshot_in_anki='', prev_screenshot_in_anki='', sentence_in_anki='', multi_line=False, video_in_anki='', word_path='', word='', extra_tags=[])
 
 
 @dataclass_json
@@ -1384,6 +1401,8 @@ def get_ffprobe_path():
 
 ffmpeg_base_command_list = [get_ffmpeg_path(), "-hide_banner", "-loglevel", "error", '-nostdin']
 
+ffmpeg_base_command_list_info = [get_ffmpeg_path(), "-hide_banner", "-loglevel", "info", '-nostdin']
+
 
 # logger.debug(f"Running in development mode: {is_dev}")
 # logger.debug(f"Running on Beangate's PC: {is_beangate}")
